@@ -19,6 +19,11 @@ def project_source_path(project_name):
     return os.path.join(project_base, 'source/')
 
 
+def project_run_path(project_name):
+    project_base = project_base_path(project_name)
+    return os.path.join(project_base, 'run/')
+
+
 def project_logs_path(project_name):
     project_base = project_base_path(project_name)
     return os.path.join(project_base, 'logs/')
@@ -41,12 +46,3 @@ def apache_conf_path():
 
     beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
     return os.path.join(beanstalk_stack_base, 'confs/', 'apache.conf')
-
-
-def app_ports_path():
-    beanstalk_settings = env.get('beanstalk_settings', None)
-    if beanstalk_settings is None:
-        abort('Load beanstalk settings first')
-
-    beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
-    return os.path.join(beanstalk_stack_base, 'confs/', 'ports.json')
