@@ -39,6 +39,5 @@ def validate_file_existence(raw_value):
 def validate_project_type(raw_value):
     if raw_value.lower() in ('plain',) + supported_projects:
         return raw_value.lower()
-    raise ValueError('\'{type}\' is not a supported project type. Use \'plain\' for other project'.format(
-        type=raw_value))
+    raise ValueError('\'{0}\' is not a supported project type. Use \'plain\' for other project'.format(raw_value))
 supported_projects = ('django',)
